import request from '@/utils/request'


export function baseMonitorInfoList(query) {
  return request({
    url: '/ems/base/baseMonitorInfo/list',
    method: 'get',
    params: query
  })
}

export function countCabinet(query) {
  return request({
    url: '/base/baseCabinetInfo/countCabinet',
    method: 'post',
    params: query
  })
}


export function selectLastTWTempertureData(query) {
  return request({
    url: '/ems/record/recordIOTInstant/selectLastTWTempertureData',
    method: 'post',
    params: {}
  })
}

export function boardTempList(query) {
  return request({
    url: '/record/recordBusbarTemp/boardTempList',
    method: 'post',
    params: query
  })
}

export function recordBusbarAlarmCount(query) {
  return request({
    url: '/record/recordBusbarAlarm/recordBusbarAlarmCount',
    method: 'post',
    params: query
  })
}

export function recordBusbarAlarmList(query) {
  return request({
    url: '/record/recordBusbarAlarm/recordBusbarAlarmList',
    method: 'post',
    params: query
  })
}
